<template>
  <div class="section-main-container layout-padding">
    <div class="section-main-padding layout-padding-auto layout-padding-view">
      <main class="financial_container">
        <!-- 开通页面start -->
        <section class="before_container" v-if="step == 0">
          <div class="financial_header">
            <div class="img_box">
              <img :src="b_wallet" />
            </div>
            <div class="header_info">
              <p class="title">企业钱包服务</p>
              <div><el-button type="primary" size="mini" @click="openStep" :disabled="!agreementCheck">立即开通</el-button>
              </div>
              <div class="agreement">
                <el-checkbox class="elcheckbox" v-model="agreementCheck"></el-checkbox>
                <span class="txttips">我已阅读并同意：<a href="https://bcxinstatic.bktang.cn/thirdparty/payagreement.pdf"
                    target="_blank">支付服务协议</a>及<a href="https://bcxinstatic.bktang.cn/thirdparty/useragreement.pdf"
                    target="_blank">用户服务协议</a>
                </span>
              </div>
            </div>
          </div>
          <div class="question_info">
            <h3>Q：钱包服务如何开通？</h3>
            <div>
              <p>企业点击上方的“立即开通”按钮，根据页面提示完成开户开通操作即可；详情可参考帮助文档 <a
                  href="https://wiki.baibaodun.cn/page/display?document_id=1906" target="_blank">企业钱包开通</a></p>
            </div>
          </div>
        </section>
        <!-- 开通页面end -->

        <!-- 申请开通start -->
        <section class="account_container" v-if="step > 0 && step < 4">
          <header class="headerbreadcrumb">
            <el-breadcrumb :separator-icon="ArrowRight">
              <el-breadcrumb-item>企业钱包</el-breadcrumb-item>
              <el-breadcrumb-item>开通钱包</el-breadcrumb-item>
            </el-breadcrumb>
          </header>
          <header class="stepsTitle">
            <el-steps :active="active" finish-status="success">
              <el-step title="填写开户资料" />
              <el-step title="绑定银行卡" />
              <el-step title="开户成功" />
            </el-steps>
          </header>
          <!-- 开通步骤step=1start -->
          <section class="stepsOne" v-if="step == 1">
            <account ref="accountRef" @stepInfo="stepInfo"></account>
          </section>
          <!-- 开通步骤step=1end -->

          <!-- 开通步骤step=2start -->
          <section class="stepsTwo" v-if="step == 2">
            <bank ref="bankRef" @stepInfo="stepInfo"></bank>
          </section>
          <!-- 开通步骤step=2end -->

          <!-- 开户成功步骤step=3start -->
          <section class="stepsThree" v-if="step == 3">
            <successaccount @walletViewBtn="walletViewBtn"></successaccount>
          </section>
          <!-- 开户成功step=3end -->
        </section>
        <!-- 申请开通end -->

        <!-- 我的钱包页面start -->
        <section class="myWallet_container" v-if="step == 4">
          <myWallet @accountStep="accountStep" @bankStep="bankStep"></myWallet>
        </section>
        <!-- 我的钱包页面end -->
      </main>
    </div>
  </div>
</template>
<script setup lang="ts" name="payAccount">
import { onMounted, ref, reactive, nextTick } from 'vue'
import { ArrowRight } from '@element-plus/icons-vue'
import b_wallet from '/@/assets/b_wallet.png'
import account from './account.vue'
import bank from './bank.vue'
import successaccount from './successaccount.vue'
import myWallet from './myWallet.vue'
import { ConfigApi } from '/@/api/api'
const agreementCheck = ref(false)
const step = ref(0)//默认
const active = ref(0)
const accountRef = ref()
const bankRef = ref()
const flag = ref(false)//判断是从我的钱包过来才加载查询账号接口，默认false
const openStep = () => {
  console.log(step)
  step.value = 1
}

//完成开户--跳到我的钱包页面
const walletViewBtn = () => {
  step.value = 4
}
//进入账户页面
const accountStep = (val: boolean) => {
  step.value = 1
  nextTick(() => {
    accountRef.value.openDialog(val)
  })
  flag.value = val
  if (flag.value) {
    active.value = 3 //开户成功active状态
  }
}
//进入银行绑定页面
const bankStep = (val: boolean) => {
  step.value = 2
  nextTick(() => {
    bankRef.value.openDialog(val)
  })
  flag.value = val
  if (flag.value) {
    active.value = 3 //开户成功active状态
  }
}
//1. 获取企业钱包服务开通情况
const walletServiceOpeninfo = () => {
  ConfigApi().walletServiceOpeninfoApi().then(async res => {
    console.log('res', res)
    const { isAuthorize, isCompleteOpen } = res.data;
    if (isAuthorize == 1 && isCompleteOpen == 1) {
      step.value = 4
    } else if (isAuthorize == 1) {
      let result = await ConfigApi().getComWalletCurrentProcessApi({});
      let process = result.data.step;
      if (isCompleteOpen == 0 && process == 1) {
        step.value = 1
        active.value = 0
      } else if (isCompleteOpen == 0 && process == 2) {
        step.value = 2
        active.value = 1
      }
    } else {
      step.value = 0
    }
  })
}
//步骤跳转
const stepInfo = (Step: number) => {
  console.log('Step', Step)
  nextTick(() => {
    step.value = Step + 1
    active.value = Step
  })
}
onMounted(() => {
  walletServiceOpeninfo()
})
</script>
<style lang="scss" scoped>
.financial_container {
  padding: 20px;
  overflow: auto;

  .before_container {
    .financial_header {
      display: flex;
      align-items: center;
      padding: 0 40px;
      border-bottom: 1px solid #ddd;
      min-height: 200px;

      .img_box {
        width: 150px;
        overflow: hidden;

        img {
          width: 100%;
        }
      }

      .header_info {
        margin-left: 30px;
        font-size: 18px;
        font-weight: bold;

        p.title {
          margin-top: 20px;
          margin-bottom: 20px;
          font-size: 33px;
        }

        .agreement {
          color: #000;
          display: flex;
          align-items: center;
          font-weight: normal;

          .elcheckbox {
            margin-right: 10px;
          }

          .txttips {
            font-size: 14px;
            color: rgba(0, 0, 0, 0.9);
          }

          a {
            color: #1890ff;
          }
        }
      }
    }

    .question_info {
      padding: 0 20px;

      h3 {
        margin-top: 40px;
        margin-bottom: 10px;
        font-size: 18px;
        font-weight: bold;
      }

      p {
        color: rgba(0, 0, 0, .65);

        a {
          color: #1890ff;
        }
      }
    }
  }

  .account_container {
    .headerbreadcrumb {
      padding: 40px 0;
    }

    .stepsTitle {
      width: 80%;
      margin: 0 auto;
      margin-bottom: 50px;
    }
  }
}

.el-breadcrumb {
  font-size: 18px;
  color: #333;
}
</style>